@@ -42,6 +42,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "config.h"
 #ifdef HAVE_LIBUSB
 
+#define _GNU_SOURCE		/* for asprintf(3) */
 #include <string.h>
 #include <sys/types.h>
 #include <stdio.h>
@@ -128,6 +129,7 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 	struct _driverTracker *driver,
 	struct _driverTracker *classdriver);
 static LONG HPRemoveHotPluggable(int reader_index);
+static void HPCleanupHotPluggable(int reader_index);
 
 static LONG HPReadBundleValues(void)
 {
@@ -211,7 +213,7 @@ static LONG HPReadBundleValues(void)
 			if (rv)
 				CFBundleName = NULL;
 			else
-				CFBundleName = strdup(list_get_at(values, 0));
+				CFBundleName = list_get_at(values, 0);
 
 			/* while we find a nth ifdVendorID in Info.plist */
 			for (alias=0; alias<list_size(manuIDs); alias++)
@@ -231,7 +233,8 @@ static LONG HPReadBundleValues(void)
 				driverTracker[listCount].bundleName = strdup(currFP->d_name);
 				driverTracker[listCount].libraryPath = strdup(fullLibPath);
 				driverTracker[listCount].ifdCapabilities = ifdCapabilities;
-				driverTracker[listCount].CFBundleName = CFBundleName;
+				driverTracker[listCount].CFBundleName =
+				   CFBundleName ? strdup(CFBundleName) : NULL;
 
 #ifdef DEBUG_HOTPLUG
 				Log2(PCSC_LOG_INFO, "Found driver for: %s",
@@ -442,10 +445,19 @@ static void HPRescanUsbBus(void)
 			HPRemoveHotPluggable(i);
 	}
 
+	/* free the libusb allocated list & devices */
+	libusb_free_device_list(devs, 1);
+
 	if (AraKiriHotPlug)
 	{
 		int retval;
 
+		for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
+		{
+			if (readerTracker[i].fullName != NULL)
+				HPCleanupHotPluggable(i);
+		}
+
 		for (i=0; i<driverSize; i++)
 		{
 			/* free strings allocated by strdup() */
@@ -459,9 +471,6 @@ static void HPRescanUsbBus(void)
 		Log1(PCSC_LOG_INFO, "Hotplug stopped");
 		pthread_exit(&retval);
 	}
-
-	/* free the libusb allocated list & devices */
-	libusb_free_device_list(devs, 1);
 }
 
 static void * HPEstablishUSBNotifications(int pipefd[2])
@@ -548,6 +557,7 @@ LONG HPSearchHotPluggables(void)
 {
 	int i;
 
+	AraKiriHotPlug = FALSE;
 	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
 		readerTracker[i].status = READER_ABSENT;
@@ -606,14 +616,17 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 	int i;
 	uint8_t iInterface = 0;
 	uint8_t iSerialNumber = 0;
-	char deviceName[MAX_DEVICENAME];
+	char *deviceName;
 
 	Log2(PCSC_LOG_INFO, "Adding USB device: %s", bus_device);
 
-	snprintf(deviceName, sizeof(deviceName), "usb:%04x/%04x:libusb-1.0:%s",
+	i = asprintf(&deviceName, "usb:%04x/%04x:libusb-1.0:%s",
 		desc.idVendor, desc.idProduct, bus_device);
-
-	deviceName[sizeof(deviceName) -1] = '\0';
+	if (-1 == i)
+	{
+		Log1(PCSC_LOG_ERROR, "asprintf() failed");
+		return 0;
+	}
 
 	pthread_mutex_lock(&usbNotifierMutex);
 
@@ -751,6 +764,8 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 
 	pthread_mutex_unlock(&usbNotifierMutex);
 
+	free(deviceName);
+
 	return 1;
 }	/* End of function */
 
@@ -763,16 +778,21 @@ static LONG HPRemoveHotPluggable(int reader_index)
 
 	RFRemoveReader(readerTracker[reader_index].fullName,
 		PCSCLITE_HP_BASE_PORT + reader_index, REMOVE_READER_FLAG_REMOVED);
-	free(readerTracker[reader_index].fullName);
-	readerTracker[reader_index].status = READER_ABSENT;
-	readerTracker[reader_index].bus_device[0] = '\0';
-	readerTracker[reader_index].fullName = NULL;
+	HPCleanupHotPluggable(reader_index);
 
 	pthread_mutex_unlock(&usbNotifierMutex);
 
 	return 1;
 }	/* End of function */
 
+static void HPCleanupHotPluggable(int reader_index)
+{
+	free(readerTracker[reader_index].fullName);
+	readerTracker[reader_index].status = READER_ABSENT;
+	readerTracker[reader_index].bus_device[0] = '\0';
+	readerTracker[reader_index].fullName = NULL;
+}	/* End of function */
+
 /**
  * Sets up callbacks for device hotplug events.
  */
