@@ -39,11 +39,18 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "config.h"
 #include <sys/time.h>
+#include <limits.h>
 #include <stdlib.h>
 #include <time.h>
+#ifdef HAVE_GETRANDOM
+#include <sys/random.h>
+#endif /* HAVE_GETRANDOM */
+#include <errno.h>
+#include <string.h>
 
 #include "misc.h"
 #include "sys_generic.h"
+#include "PCSC/debuglog.h"
 
 /**
  * @brief Makes the current process sleep for some seconds.
@@ -87,22 +94,40 @@ INTERNAL int SYS_USleep(int iTimeVal)
 /**
  * Generate a pseudo random number
  *
- * @param[in] fStart minimal value
- * @param[in] fEnd maximal value or -1 for a full range
+ * @return a non-negative random number
  *
- * @return a random number between fStart and fEnd
+ * @remark the range is at least up to `2^31`.
+ * @remark this is a CSPRNG when `getrandom()` is available, LCG otherwise.
+ * @warning SYS_InitRandom() should be called (once) before using this function.
+ * @warning not thread safe when system lacks `getrandom()` syscall.
+ * @warning not cryptographically secure when system lacks `getrandom()` syscall.
+ * @warning if interrupted by a signal, this function may return 0.
  */
-INTERNAL int SYS_RandomInt(int fStart, int fEnd)
+INTERNAL int SYS_RandomInt(void)
 {
-	int iRandNum = 0;
+#ifdef HAVE_GETRANDOM
+	unsigned int ui = 0;
+	unsigned char c[sizeof ui] = {0};
+	size_t i;
+	ssize_t ret;
 
-	if (-1 == fEnd)
-		/* full int range */
-		iRandNum = rand();
-	else
-		iRandNum = ((rand()+0.0)/RAND_MAX * (fEnd - fStart)) + fStart;
-
-	return iRandNum;
+	ret = getrandom(c, sizeof c, 0);
+	if (-1 == ret)
+	{
+		Log2(PCSC_LOG_ERROR, "getrandom() failed: %s", strerror(errno));
+		return lrand48();
+	}
+	// this loop avoids trap representations that may occur in the naive solution
+	for(i = 0; i < sizeof ui; i++) {
+		ui <<= CHAR_BIT;
+		ui |= c[i];
+	}
+	// the casts are for the sake of clarity
+	return (int)(ui & (unsigned int)INT_MAX);
+#else
+	int r = lrand48(); // this is not thread-safe
+	return r;
+#endif /* HAVE_GETRANDOM */
 }
 
 /**
@@ -110,6 +135,7 @@ INTERNAL int SYS_RandomInt(int fStart, int fEnd)
  */
 INTERNAL void SYS_InitRandom(void)
 {
+#ifndef HAVE_GETRANDOM
 	struct timeval tv;
 	struct timezone tz;
 	long myseed = 0;
@@ -124,6 +150,7 @@ INTERNAL void SYS_InitRandom(void)
 		myseed = (long) time(NULL);
 	}
 
-	srand(myseed);
+	srand48(myseed);
+#endif /* HAVE_GETRANDOM */
 }
 
